@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-typing-booster - A completion input method for IBus
@@ -249,11 +248,11 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             itb_util.xdg_save_data_path('emoji-picker'),
             'options')
         self._read_options()
-        if not font is None:
+        if font is not None:
             self._font = font
-        if not fontsize is None:
+        if fontsize is not None:
             self._fontsize = fontsize
-        if not fallback is None:
+        if fallback is not None:
             self._fallback = bool(fallback)
         self._save_options()
         self.connect('destroy-event', self.on_destroy_event)
@@ -261,10 +260,10 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         self.connect('key-press-event', self.on_main_window_key_press_event)
         self._languages = languages
         self._emoji_unicode_min = '0.0'
-        if not emoji_unicode_min is None:
+        if emoji_unicode_min is not None:
             self._emoji_unicode_min = emoji_unicode_min
         self._emoji_unicode_max = '100.0'
-        if not emoji_unicode_max is None:
+        if emoji_unicode_max is not None:
             self._emoji_unicode_max = emoji_unicode_max
 
         self._unicode_data_all = unicode_data_all
@@ -600,7 +599,7 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
             label_key_display: str,
             language: str,
             language_iter: Any) -> bool:
-        if not label_key in self._emoji_by_label[language]:
+        if label_key not in self._emoji_by_label[language]:
             return False
         labels = self._sort_labels(
             self._emoji_by_label[language][label_key],
@@ -888,7 +887,6 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         if os.path.isfile(self._options_file):
             try:
                 with open(self._options_file,
-                          mode='r',
                           encoding='UTF-8') as options_file:
                     options_dict = ast.literal_eval(options_file.read())
             except (PermissionError, SyntaxError, IndentationError) as error:
@@ -954,7 +952,6 @@ class EmojiPickerUI(Gtk.Window): # type: ignore
         if os.path.isfile(self._recently_used_emoji_file):
             try:
                 with open(self._recently_used_emoji_file,
-                          mode='r',
                           encoding='UTF-8') as recently_used_file:
                     recently_used_emoji = ast.literal_eval(
                         recently_used_file.read())
