@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-typing-booster - A completion input method for IBus
@@ -28,6 +27,7 @@ from typing import Dict
 from typing import Tuple
 from typing import List
 from typing import Iterable
+from typing import Any
 import os
 import sys
 import unicodedata
@@ -41,7 +41,7 @@ try:
     # Enable new improved regex engine instead of backwards compatible
     # v0.  regex.match('ß', 'SS', regex.IGNORECASE) matches only with
     # the improved version!  See also: https://pypi.org/project/regex/
-    regex.DEFAULT_VERSION = regex.VERSION1
+    regex.DEFAULT_VERSION = regex.VERSION1 # pylint: disable=no-member
 except (ImportError,):
     # Use standard “re” module as a fallback:
     import re
@@ -77,12 +77,31 @@ except (ImportError,):
 # letter of a word until the candidate lookup table pops up.
 MAX_WORDS = 100
 
-class Dictionary:
-    '''A class to hold a hunspell dictionary
-    '''
-    def __init__(self, name: str = 'en_US') -> None:
+# pylint: disable=attribute-defined-outside-init
+class Dictionary():
+    '''A class to hold a hunspell dictionary'''
+    # As soon as it is OK ot require Python >= 3.7, use these nicer type hints:
+    #
+    # _instances: Dict[Tuple[Type['Dictionary'], str], 'Dictionary'] = {}
+    #
+    # def __new__(cls: Type['Dictionary'], name: str = 'en_US') -> 'Dictionary':
+    #
+    # openSUSE Leap 15.4 still has only Python 3.6.
+    _instances: Dict[Tuple[Any, str], Any] = {}
+
+    def __new__(cls: Any, name: str = 'en_US') -> Any:
+        '''Caching instances of this class and reuse previously created instances'''
+        key = (cls, name)
+        if key not in cls._instances:
+            instance = super().__new__(cls)
+            cls._instances[key] = instance
+            instance._initialize(name=name)
+        return cls._instances[key]
+
+    def _initialize(self, name: str = 'en_US') -> None:
+        '''Initialize a Dictionary'''
         if DEBUG_LEVEL > 1:
-            LOGGER.debug('Dictionary.__init__(name=%s)\n', name)
+            LOGGER.debug('name=%s', name)
         self.name = name
         self.language = self.name.split('_')[0]
         self.dic_path = ''
@@ -142,7 +161,7 @@ class Dictionary:
                         'Error initializing enchant for %s: %s: %s',
                         self.name, error.__class__.__name__, error)
                     self.enchant_dict = None
-                except Exception as error:
+                except Exception as error: # pylint: disable=broad-except
                     LOGGER.exception(
                         'Unexpected error initializing enchant for %s: %s: %s',
                         self.name, error.__class__.__name__, error)
@@ -150,14 +169,15 @@ class Dictionary:
             elif IMPORT_HUNSPELL_SUCCESSFUL and self.dic_path:
                 aff_path = self.dic_path.replace('.dic', '.aff')
                 try:
-                    self.pyhunspell_object = hunspell.HunSpell(
-                        self.dic_path, aff_path)
+                    self.pyhunspell_object = (
+                        hunspell.HunSpell( # pylint: disable=used-before-assignment
+                            self.dic_path, aff_path))
                 except hunspell.HunSpellError as error:
                     LOGGER.debug(
                         'Error initializing hunspell for %s: %s: %s',
                         self.name, error.__class__.__name__, error)
                     self.pyhunspell_object = None
-                except Exception as error:
+                except Exception as error: # pylint: disable=broad-except
                     LOGGER.debug(
                         'Unexpected error initializing hunspell for '
                         '%s: %s: %s',
@@ -345,13 +365,14 @@ class Dictionary:
         if self.voikko:
             return self.spellcheck_suggest_voikko(word)
         return []
+# pylint: enable=attribute-defined-outside-init
 
 class Hunspell:
     '''A class to suggest completions or corrections
     using a list of Hunspell dictionaries
     '''
     def __init__(self, dictionary_names: Iterable[str] = ()) -> None:
-        global DEBUG_LEVEL
+        global DEBUG_LEVEL # pylint: disable=global-statement
         try:
             DEBUG_LEVEL = int(
                 str(os.getenv('IBUS_TYPING_BOOSTER_DEBUG_LEVEL')))
@@ -503,15 +524,16 @@ class Hunspell:
                 match_list.append(dictionary.name)
         return match_list
 
-    def spellcheck_single_dictionary(self, words: Iterable[str] = ()) -> bool:
+    def spellcheck_single_dictionary(self, words: Iterable[str] = ()) -> List[str]:
         '''
         Checks whether there is at least one dictionary where all words
         in the input list spellcheck as True.
 
         :param words: A list or tuple of words to spellcheck
-        :return: - False if at least one input word is empty
-                 - True if there is at least one dictionary where all
-                   words in the input list spellcheck as True, else False.
+        :return: - '' if at least one input word is empty
+                 - name of a dictionary where all
+                   words in the input list spellcheck as True, if
+                   there is no such dictionary, return ''.
 
         Examples:
 
@@ -520,49 +542,54 @@ class Hunspell:
         All 3 words spellcheck True in the French dictionary:
 
         >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrivé'))
-        True
+        ['fr_FR']
 
         Not a correct French sentence but all 3 words spellcheck True
         in the French dictionary:
 
         >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrive'))
-        True
+        ['fr_FR']
 
+        All words spellcheck as True in both the English and the French dictionary:
+
+        >>> h.spellcheck_single_dictionary(('arrive', 'arrive', 'arrive'))
+        ['en_US', 'fr_FR']
 
         Not all 3 words spellcheck True in the French dictionary and
         not all 3 words spellcheck True in the English dictionary either:
 
         >>> h.spellcheck_single_dictionary(('Je', 'suis', 'arrived'))
-        False
+        []
 
         All 3 words spellcheck True in the English dictionary:
 
         >>> h.spellcheck_single_dictionary(('I', 'have', 'arrived'))
-        True
+        ['en_US']
 
         Unfortunately these 3 words spellcheck True in the French dictionary
         ('have' is a form of the verb 'haver', 'I' is the name of the letter):
 
         >>> h.spellcheck_single_dictionary(('I', 'have', 'arrivé'))
-        True
+        ['fr_FR']
 
-        If the input contains empty words the result is False:
+        If the input contains empty words the result is '':
 
         >>> h.spellcheck_single_dictionary(('I', 'have', ''))
-        False
+        []
         '''
         if not words:
-            return False
+            return []
         for word in words:
             if not word:
-                return False
+                return []
+        dictionary_names = []
         for dictionary in self._dictionaries:
             spellcheck_total = True
             for word in words:
                 spellcheck_total &= dictionary.spellcheck(word)
             if spellcheck_total:
-                return True
-        return False
+                dictionary_names.append(dictionary.name)
+        return sorted(dictionary_names)
 
     def suggest(self, input_phrase: str) -> List[Tuple[str, int]]:
         # pylint: disable=line-too-long
@@ -677,7 +704,7 @@ class Hunspell:
                                 for x in dictionary.word_pairs
                                 if regex_pattern.match(x[1])])
                         else:
-                            re_pattern = re.compile(
+                            re_pattern = re.compile( # pylint: disable=used-before-assignment
                                 re.escape(input_phrase_no_accents),
                                 re.IGNORECASE)
                             suggested_words.update([
@@ -752,6 +779,11 @@ def main() -> None:
     runs some tests and prints profiling data.
     '''
     log_handler = logging.StreamHandler(stream=sys.stderr)
+    log_formatter = logging.Formatter(
+        '%(asctime)s %(filename)s '
+        'line %(lineno)d %(funcName)s %(levelname)s: '
+        '%(message)s')
+    log_handler.setFormatter(log_formatter)
     LOGGER.setLevel(logging.DEBUG)
     LOGGER.addHandler(log_handler)
 
