@@ -1,4 +1,3 @@
-# -*- coding: utf-8 -*-
 # vim:et sts=4 sw=4
 #
 # ibus-typing-booster - A completion input method for IBus
@@ -941,6 +940,33 @@ class Transliterator:
     >>> trans.transliterate(list('namaste'))
     'नमस्ते'
 
+    >>> trans.transliterate_parts(list('n'))
+    ('', 'न्')
+
+    >>> trans.transliterate_parts(list('n '))
+    ('न ', '')
+
+    >>> trans.transliterate_parts(list('na'))
+    ('', 'न')
+
+    >>> trans.transliterate_parts(list('nam'))
+    ('न', 'म्')
+
+    >>> trans.transliterate_parts(list('nama'))
+    ('न', 'म')
+
+    >>> trans.transliterate_parts(list('namas'))
+    ('नम', 'स्')
+
+    >>> trans.transliterate_parts(list('namast'))
+    ('नम', 'स्त्')
+
+    >>> trans.transliterate_parts(list('namaste'))
+    ('नम', 'स्ते')
+
+    >>> trans.transliterate_parts(list('namaste '))
+    ('नमस्ते ', '')
+
     >>> trans.transliterate(list('. '))
     '। '
 
@@ -982,7 +1008,7 @@ class Transliterator:
     >>> trans.transliterate(list('annyeonghaseyo'))
     '안녕하세요'
 
-    >>> trans = Transliterator('si-wijesekera')
+    >>> trans = Transliterator('si-wijesekara')
     >>> trans.transliterate(list('vksIal kjSka '))
     'ඩනිෂ්ක නවීන් '
 
@@ -1019,7 +1045,7 @@ class Transliterator:
         except ValueError as error: # NULL pointer access
             raise ValueError('minput_create_ic() failed') from error
 
-    def transliterate(self, msymbol_list: Iterable[str], ascii_digits: bool = False) -> str:
+    def transliterate_parts(self, msymbol_list: Iterable[str], ascii_digits: bool = False) -> Tuple[str, str]:
         '''Transliterate a list of Msymbol names
 
         :param msymbol_list: A list of strings which are interpreted
@@ -1029,14 +1055,15 @@ class Transliterator:
                              Msymbols is just joined to a single string.
         :param ascii_digits: If true, convert language specific digits
                              to ASCII digits
-        :return: The transliteration
+        :return: The transliteration in two parts: (committed, preedit)
         '''
         if not isinstance(msymbol_list, list):
             raise ValueError('Argument of transliterate() must be a list.')
         if self._dummy:
-            return ''.join(msymbol_list)
+            return (''.join(msymbol_list), '')
         libm17n__minput_reset_ic(self._ic) # type: ignore
-        output = ''
+        committed = ''
+        preedit = ''
         for symbol in msymbol_list:
             _symbol = libm17n__msymbol(symbol.encode('utf-8')) # type: ignore
             retval = libm17n__minput_filter( # type: ignore
@@ -1046,15 +1073,15 @@ class Transliterator:
                 retval = libm17n__minput_lookup( # type: ignore
                     self._ic, _symbol, ctypes.c_void_p(None), _mt)
                 if libm17n__mtext_len(_mt) > 0: # type: ignore
-                    output += mtext_to_string(_mt)
+                    committed += mtext_to_string(_mt)
                 if retval:
-                    output += symbol
+                    committed += symbol
         try:
             if (self._ic.contents.preedit_changed
                 and
                 libm17n__mtext_len(
                     self._ic.contents.preedit) > 0): # type: ignore
-                output += mtext_to_string(self._ic.contents.preedit)
+                preedit = mtext_to_string(self._ic.contents.preedit)
         except Exception as error: # pylint: disable=broad-except
             # This should never happen:
             raise ValueError('Problem accessing preedit') from error
@@ -1077,15 +1104,30 @@ class Transliterator:
         # always appended a final 'nil' symbol to the msymbol_list
         # argument which had to be removed to get the correct preedit
         # contents.  But apparently that final 'nil' is necessary to
-        # make it work reliably. We can do this here because above we read
-        # the preedit and added it to 'output' already and don’t
-        # need it anymore.
-        _symbol = libm17n__msymbol('nil'.encode('utf-8')) # type: ignore
+        # make it work reliably. We can do this here because above we
+        # read the preedit already and don’t need it anymore.
+        _symbol = libm17n__msymbol(b'nil') # type: ignore
         _retval = libm17n__minput_filter( # type: ignore
             self._ic, _symbol, ctypes.c_void_p(None))
         if not ascii_digits:
-            return output
-        return convert_digits_to_ascii(output)
+            return (committed, preedit)
+        return (convert_digits_to_ascii(committed),
+                convert_digits_to_ascii(preedit))
+
+    def transliterate(self, msymbol_list: Iterable[str], ascii_digits: bool = False) -> str:
+        '''Transliterate a list of Msymbol names
+
+        :param msymbol_list: A list of strings which are interpreted
+                             as the names of Msymbols to transliterate.
+                             If the input method has the special name “NoIME”,
+                             no transliteration is done, the list of
+                             Msymbols is just joined to a single string.
+        :param ascii_digits: If true, convert language specific digits
+                             to ASCII digits
+        :return: The transliteration in one string
+        '''
+        (committed, preedit) = self.transliterate_parts(msymbol_list, ascii_digits)
+        return committed + preedit
 
     def get_variables(self) -> List[Tuple[str, str, str]]:
         # pylint: disable=line-too-long
@@ -1097,7 +1139,7 @@ class Transliterator:
         >>> trans = Transliterator('NoIME')
         >>> trans.get_variables()
         []
-        >>> trans = Transliterator('si-wijesekera')
+        >>> trans = Transliterator('si-wijesekara')
         >>> trans.get_variables()
         [('use-surrounding-text', 'Surrounding text vs. preedit.\\nIf 1, try to use surrounding text.  Otherwise, use preedit.', '0')]
         >>> trans = Transliterator('t-unicode')
@@ -1111,7 +1153,7 @@ class Transliterator:
         plist = libm17n__minput_get_variable( # type: ignore
             libm17n__msymbol(self._language.encode('utf-8')), # type: ignore
             libm17n__msymbol(self._name.encode('utf-8')), # type: ignore
-            libm17n__msymbol('nil'.encode('utf-8'))) # type: ignore
+            libm17n__msymbol(b'nil')) # type: ignore
         while bool(plist): # NULL pointers have a False boolean value
             key = libm17n__mplist_key(plist) # type: ignore
             if not bool(key): # NULL pointers have a False boolean value
@@ -1230,7 +1272,7 @@ class Transliterator:
                 if key_name == b'symbol':
                     libm17n__mplist_add( # type: ignore
                         new_value_plist,
-                        libm17n__msymbol('symbol'.encode('utf-8')), # type: ignore
+                        libm17n__msymbol(b'symbol'), # type: ignore
                         libm17n__msymbol(variable_value.encode('utf-8'))) # type: ignore
                 elif key_name == b'mtext':
                     mtext = libm17n__mconv_decode_buffer( # type: ignore
@@ -1239,14 +1281,14 @@ class Transliterator:
                         len(variable_value.encode('utf-8')))
                     libm17n__mplist_add( # type: ignore
                         new_value_plist,
-                        libm17n__msymbol('mtext'.encode('utf-8')), # type: ignore
+                        libm17n__msymbol(b'mtext'), # type: ignore
                         mtext)
                 elif key_name == b'integer':
                     try:
                         int_value = int(variable_value, 10)
                         libm17n__mplist_add( # type: ignore
                             new_value_plist,
-                            libm17n__msymbol('integer'.encode('utf-8')), # type: ignore
+                            libm17n__msymbol(b'integer'), # type: ignore
                             int_value)
                     except ValueError:
                         new_value_plist = libm17n__mplist() # type: ignore
